import { startTunnel } from './tunnel.js';
import chalk from 'chalk';
/**
 * Zuby.js plugin that allows you to easily
 * share your local server with anyone over the internet
 * using Cloudflare Quick Tunnels.
 * @returns ZubyPlugin
 */
export default () => ({
    name: 'zuby-share-plugin',
    description: 'Share your local development server with anyone over the internet',
    hooks: {
        'zuby:dev:start': createTunnel,
        'zuby:preview:start': createTunnel,
    },
});
export async function createTunnel({ config }) {
    const { server, customLogger: logger } = config;
    const hostname = server?.host;
    const port = server?.port;
    if (!hostname || !port)
        return;
    const tunnel = await startTunnel({
        hostname,
        port,
        verifyTLS: false,
    });
    if (!tunnel) {
        return logger.error('  ┃ Share: Failed to start the tunnel');
    }
    const tunnelUrl = await tunnel.getURL();
    logger?.info(`  ┃ Share  ${chalk.gray(tunnelUrl)}\r\n`);
}
